@@ -1,10 +1,10 @@
-use 5.20.0;
+use 5.16.0;
 use Map::Metro::Standard;
 
 
 package Map::Metro {
 
-    our $VERSION = '0.2201'; # VERSION
+    our $VERSION = '0.2202'; # VERSION
     # ABSTRACT: Public transport graphing
     use Moose;
     use Module::Pluggable search_path => ['Map::Metro::Plugin::Map'], require => 1, sub_name => 'system_maps';
@@ -12,7 +12,6 @@ package Map::Metro {
     use Types::Standard -types;
     use Types::Path::Tiny -types;
     use List::AllUtils 'any';
-    use experimental qw/postderef/;
 
     use Map::Metro::Graph;
 
@@ -131,7 +130,7 @@ Map::Metro - Public transport graphing
 
 =head1 VERSION
 
-Version 0.2201, released 2015-01-09.
+Version 0.2202, released 2015-01-13.
 
 =head1 SYNOPSIS
 
@@ -280,7 +279,7 @@ For all maps in the Map::Metro::Plugin::Map namespace (unless noted):
 
 =head1 COMPATIBILITY
 
-Currently only Perl 5.20+ is supported.
+Currently requires Perl 5.16.
 
 =head1 Map::Metro or Map::Tube?
 
