@@ -1,13 +1,12 @@
 use Map::Metro::Standard::Moops;
 
-our $VERSION = '0.2201'; # VERSION
+our $VERSION = '0.2202'; # VERSION
 # PODNAME: Map::Metro::Cmd::Stations
 
 class Map::Metro::Cmd::Stations extends Map::Metro::Cmd using Moose {
 
     use MooseX::App::Command;
     use Term::Size::Any 'chars';
-    use experimental 'postderef';
 
     parameter cityname => (
         is => 'rw',
@@ -37,18 +36,18 @@ class Map::Metro::Cmd::Stations extends Map::Metro::Cmd using Moose {
 
         foreach (1..$column_count) {
             my $column = [];
-            while(scalar $column->@* < $max_per_column && scalar @station_texts) {
+            while(scalar @$column < $max_per_column && scalar @station_texts) {
                 my $text = shift @station_texts;
                 my $padding = ' ' x ($column_width - length $text);
 
-                push $column->@* => $text . $padding;
+                push @$column => $text . $padding;
             }
-            push $columns->@* => $column;
+            push @$columns => $column;
         }
 
         say join "\n" => '', $intro_text, '';
-        foreach my $row (0..scalar $columns->[0]->@* - 1) {
-            foreach my $column ($columns->@*) {
+        foreach my $row (0..scalar @{ $columns->[0] } - 1) {
+            foreach my $column (@$columns) {
                 print $column->[$row] if $column->[$row];
             }
             say '';
@@ -75,7 +74,7 @@ Map::Metro::Cmd::Stations
 
 =head1 VERSION
 
-Version 0.2201, released 2015-01-09.
+Version 0.2202, released 2015-01-13.
 
 =head1 SOURCE
 
