@@ -1,6 +1,6 @@
 use Map::Metro::Standard::Moops;
 
-our $VERSION = '0.2201'; # VERSION
+our $VERSION = '0.2202'; # VERSION
 # PODNAME: Map::Metro::Graph
 # ABSTRACT: An entire graph
 
@@ -259,7 +259,7 @@ class Map::Metro::Graph using Moose {
 
         my $transfer = Map::Metro::Graph::Transfer->new(origin_station => $origin_station,
                                                         destination_station => $destination_station,
-                                                        $options->%*);
+                                                        %$options);
 
         $self->$next($transfer);
     }
@@ -398,7 +398,7 @@ class Map::Metro::Graph using Moose {
         foreach my $option (@options) {
             my($key, $value) = split /:/ => $option;
 
-            next OPTION if scalar $keys->@* && (none { $key eq $_ } $keys->@*);
+            next OPTION if scalar @$keys && (none { $key eq $_ } @$keys);
             $options->{ $key } = $value;
         }
         return $options;
@@ -512,28 +512,36 @@ class Map::Metro::Graph using Moose {
 
         }
     }
-    multi method routing_for(Int $origin_id, Int $destination_id) {
-        my $origin = $self->get_station_by_id($origin_id);
-        my $dest = $self->get_station_by_id($destination_id);
 
-        return $self->routing_for($origin->name, $dest->name);
-    }
+    method ensure_station(Int|Str|Station $place
+                      --> Station but assumed
+    ) {
+
+        return $place if Station->check($place);
 
-    multi method routing_for(Str $origin_name, Str $destination_name) {
-        my($origin_station, $destination_station);
         try {
-            $origin_station = $self->get_station_by_name($origin_name);
-            $destination_station = $self->get_station_by_name($destination_name);
+            if(Int->check($place)) {
+                $place = $self->get_station_by_id($place);
+            }
+            else {
+                $place = $self->get_station_by_name($place);
+            }
         }
         catch {
             my $error = $_;
             $error->does('Map::Metro::Exception') ? $error->throw : die $error;
         };
-
-        return $self->routing_for($origin_station, $destination_station);
+        return $place;
     }
 
-    multi method routing_for(Station $origin_station, Station $destination_station) {
+    method routing_for(Int|Str|Station $origin!      does doc('The first station. Station id, name or object.'),
+                       Int|Str|Station $destination! does doc('The final station. Station id, name or object.')
+                   --> Routing but assumed
+    ) {
+
+        my $origin_station = $self->ensure_station($origin);
+        my $destination_station = $self->ensure_station($destination);
+
         my @origin_line_station_ids = map { $_->line_station_id } $self->get_line_stations_by_station($origin_station);
         my @destination_line_station_ids = map { $_->line_station_id } $self->get_line_stations_by_station($destination_station);
 
@@ -568,7 +576,7 @@ class Map::Metro::Graph using Moose {
                 my($prev_step, $prev_conn, $next_step, $next_conn);
 
                 LINE_STATION:
-                foreach my $index (0 .. scalar $graphroute->@* - 2) {
+                foreach my $index (0 .. scalar @$graphroute - 2) {
                     my $this_line_station_id = $graphroute->[ $index ];
                     my $next_line_station_id = $graphroute->[ $index + 1 ];
                     my $next_next_line_station_id = $graphroute->[ $index + 2 ] // undef;
@@ -578,7 +586,7 @@ class Map::Metro::Graph using Moose {
                     my $conn = $self->get_connection_by_line_station_ids($this_line_station_id, $next_line_station_id);
 
                     #* Don't continue beyond this route, even it connections exist.
-                    if($index + 2 < scalar $graphroute->@*) {
+                    if($index + 2 < scalar @$graphroute) {
                         $next_conn = defined $next_next_line_station_id ? $self->get_connection_by_line_station_ids($this_line_station_id, $next_line_station_id) : undef;
                         $next_step = Map::Metro::Graph::Step->new(from_connection => $next_conn) if defined $next_conn;
                     }
@@ -599,7 +607,7 @@ class Map::Metro::Graph using Moose {
                 }
 
                 LINE_STATION:
-                foreach my $index (0 .. scalar $graphroute->@* - 1) {
+                foreach my $index (0 .. scalar @$graphroute - 1) {
                     my $line_station = $self->get_line_station_by_id($graphroute->[$index]);
 
                     $route->add_line_station($line_station);
@@ -628,7 +636,7 @@ class Map::Metro::Graph using Moose {
 
             OTHER_STATION:
             foreach my $other_station (@other_stations) {
-                push $routings->@* => $self->routing_for($station, $other_station);
+                push @$routings => $self->routing_for($station, $other_station);
             }
         }
         return $routings;
@@ -648,7 +656,7 @@ Map::Metro::Graph - An entire graph
 
 =head1 VERSION
 
-Version 0.2201, released 2015-01-09.
+Version 0.2202, released 2015-01-13.
 
 =head1 SYNOPSIS
 
@@ -678,7 +686,31 @@ Version 0.2201, released 2015-01-09.
 This class is at the core of L<Map::Metro>. After a map has been parsed the returned instance of this class contains
 the entire network (graph) in a hierarchy of objects.
 
-=head2 Methods
+
+
+=head1 Methods
+
+
+=head2 routing_for
+
+=begin HTML
+
+<p></p>
+
+<table style="margin-bottom: 10px;" cellpadding="0" cellspacing="0">
+                        <tr style="vertical-align: top;"><th style="text-align: left; color: #444; background-color: #eee;" colspan="5">Positional parameters</th><tr><tr style="vertical-align: top;"><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><code>$origin</code>
+
+</td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><a href="http://search.cpan.org/perldoc?Types::Standard#Int">Int</a> | <a href="http://search.cpan.org/perldoc?Types::Standard#Str">Str</a> | <a href="http://search.cpan.org/perldoc?Types::Standard#Station">Station</a>
+
+</td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;">required, <span style="color: #999;">no default</span></td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><span style="color: #aaa;">no traits</span></td><td style="padding: 3px 6px; border-bottom: 1px solid #eee;">The first station. Station id, name or object.<br /></td></tr><tr style="vertical-align: top;"><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><code>$destination</code>
+
+</td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><a href="http://search.cpan.org/perldoc?Types::Standard#Int">Int</a> | <a href="http://search.cpan.org/perldoc?Types::Standard#Str">Str</a> | <a href="http://search.cpan.org/perldoc?Types::Standard#Station">Station</a>
+
+</td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;">required, <span style="color: #999;">no default</span></td><td style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><span style="color: #aaa;">no traits</span></td><td style="padding: 3px 6px; border-bottom: 1px solid #eee;">The final station. Station id, name or object.<br /></td></tr>  <tr style="vertical-align: top;"><th style="text-align: left; color: #444; background-color: #eee;" colspan="4">Returns</th><tr><tr style="vertical-align: top;"><td colspan="5" style="padding: 3px 6px; border-right: 1px solid #eee; border-bottom: 1px solid #eee;"><a href="http://search.cpan.org/perldoc?Map::Metro::Types#Routing">Routing</a>
+
+</td></tr></table>
+
+=end HTML
 
 =head3 routing_for($from, $to)
 
