@@ -1,16 +1,17 @@
-use 5.20.0;
+use 5.16.0;
 
-our $VERSION = '0.2201'; # VERSION
+our $VERSION = '0.2202'; # VERSION
 
-package Map::Metro::Standard::Moops {
+package #
+    Map::Metro::Standard::Moops {
 
     use base 'Moops';
     use List::AllUtils();
-    use experimental();
     use Map::Metro::Types();
     use Eponymous::Hash();
     use List::Compare();
     use MooseX::SetOnce();
+    use MooseX::AttributeDocumented();
 
     sub import {
         my $class = shift;
@@ -20,11 +21,11 @@ package Map::Metro::Standard::Moops {
             'List::AllUtils'    => [qw/any none sum uniq/],
             'Eponymous::Hash'   => ['eh'],
             'String::Trim'      => ['trim'],
-            'feature'           => [qw/:5.20/],
-            'experimental'      => [qw/postderef/],
+            'feature'           => [qw/:5.16/],
             'Map::Metro::Types' => [{ replace => 1 }, '-types'],
             'List::Compare'     => [],
             'MooseX::SetOnce'   => [],
+            'MooseX::AttributeDocumented' => [],
         );
 
         $class->SUPER::import(%opts);
@@ -45,7 +46,7 @@ Map::Metro::Standard::Moops
 
 =head1 VERSION
 
-Version 0.2201, released 2015-01-09.
+Version 0.2202, released 2015-01-13.
 
 =head1 SOURCE
 
